==> jc-1.4.0.tar.gz: scm/SchemeError.h <==
// public class scm.SchemeError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 1c8af52ffe27d5f6 scm_SchemeError

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_scm_SchemeError_H_
#define _JC_scm_SchemeError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_scm_SchemeError$sub_refs	_jc_scm_SchemeError$sub_refs;
typedef struct _jc_scm_SchemeError$sub_nonrefs	_jc_scm_SchemeError$sub_nonrefs;
typedef struct _jc_scm_SchemeError$refs	_jc_scm_SchemeError$refs;
typedef struct _jc_scm_SchemeError$nonrefs	_jc_scm_SchemeError$nonrefs;
typedef struct _jc_scm_SchemeError$object	_jc_scm_SchemeError$object;

typedef const struct _jc_scm_SchemeError$vmethods	_jc_scm_SchemeError$vmethods;
typedef const struct _jc_scm_SchemeError$vtable	_jc_scm_SchemeError$vtable;
typedef const struct _jc_scm_SchemeError$vtype	_jc_scm_SchemeError$vtype;

// Constructors
extern void _jc_scm_SchemeError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_SchemeError$object *);
extern void _jc_scm_SchemeError$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_SchemeError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_scm_SchemeError$vmethods {
};

// Vtable
struct _jc_scm_SchemeError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_scm_SchemeError$vmethods	scm_SchemeError;
};

// Vtype
struct _jc_scm_SchemeError$vtype {
	_jc_type			type;
	_jc_scm_SchemeError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_SchemeError$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_SchemeError$refs {
    _jc_scm_SchemeError$sub_refs	scm_SchemeError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_SchemeError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_SchemeError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_scm_SchemeError$sub_nonrefs	scm_SchemeError;
};

// Object instance structure
struct _jc_scm_SchemeError$object {
	_jc_scm_SchemeError$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_SchemeError$vtype	*vtype;
	_jc_scm_SchemeError$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_SchemeError$vtype _jc_scm_SchemeError$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_SchemeError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_SchemeError$class_object;

#endif	/* _JC_scm_SchemeError_H_ */

==> jc-1.4.6.tar.gz: scm/SchemeError.h <==
// public class scm.SchemeError

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 1c8af52ffe27d5f6 scm_SchemeError

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_scm_SchemeError_H_
#define _JC_scm_SchemeError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_scm_SchemeError$sub_refs	_jc_scm_SchemeError$sub_refs;
typedef struct _jc_scm_SchemeError$sub_nonrefs	_jc_scm_SchemeError$sub_nonrefs;
typedef struct _jc_scm_SchemeError$refs	_jc_scm_SchemeError$refs;
typedef struct _jc_scm_SchemeError$nonrefs	_jc_scm_SchemeError$nonrefs;
typedef struct _jc_scm_SchemeError$object	_jc_scm_SchemeError$object;

typedef const struct _jc_scm_SchemeError$vmethods	_jc_scm_SchemeError$vmethods;
typedef const struct _jc_scm_SchemeError$vtable	_jc_scm_SchemeError$vtable;
typedef const struct _jc_scm_SchemeError$vtype	_jc_scm_SchemeError$vtype;

// Constructors
extern void _jc_scm_SchemeError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_SchemeError$object *) _JC_JCNI_ATTR;
extern void _jc_scm_SchemeError$method$_init$c31b894660454d13(_jc_env *, struct _jc_scm_SchemeError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_scm_SchemeError$vmethods {
};

// Vtable
struct _jc_scm_SchemeError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_scm_SchemeError$vmethods	scm_SchemeError;
};

// Vtype
struct _jc_scm_SchemeError$vtype {
	_jc_type			type;
	_jc_scm_SchemeError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_SchemeError$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_SchemeError$refs {
    _jc_scm_SchemeError$sub_refs	scm_SchemeError;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_SchemeError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_SchemeError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_scm_SchemeError$sub_nonrefs	scm_SchemeError;
};

// Object instance structure
struct _jc_scm_SchemeError$object {
	_jc_scm_SchemeError$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_SchemeError$vtype	*vtype;
	_jc_scm_SchemeError$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_SchemeError$vtype _jc_scm_SchemeError$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_SchemeError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_SchemeError$class_object;

#endif	/* _JC_scm_SchemeError_H_ */
